# --------------------------------------------------------------------------- #
# Copyright (c) 2021 MOVINDOT ART S.R.L. (movindot.com). All rights reserved. #
# See eula.txt in the project root for license information.                   #
# --------------------------------------------------------------------------- #

"""The Animator's rig control properties UI."""

import PySide2.QtWidgets as qtw
import PySide2.QtGui as qtg
import puppeteer.rigcontrol as rigcontrol
import puppeteer.ui as ui


def createRigControlPropertiesUI(state):
    """Create the UI for the selected rig controls' properties."""
    with ui.GroupVBox('Properties') as mainBox:
        ui.bind(mainBox, state.uiState, 'rigControlPropertiesCollapsed')

        with qtw.QFormLayout() as formLayout:
            targetField = ui.NodeField(hasPickButton=False)
            targetField.setNode(state.selectedRigControl.obj.target)

            shapeTypeField = qtw.QComboBox()
            shapeTypeField.setSizePolicy(qtw.QSizePolicy.Expanding, qtw.QSizePolicy.Minimum)

            for shapeType in rigcontrol.ShapeType:
                shapeTypeField.addItem(shapeType.name.lower(), shapeType.value)

            shapeTypeField.insertSeparator(5)
            shapeTypeField.insertSeparator(12)

            sizeField = qtw.QLineEdit()
            sizeValidator = qtg.QDoubleValidator()
            sizeValidator.setBottom(0)
            sizeValidator.setDecimals(3)
            sizeField.setValidator(sizeValidator)

            innerSizeField = ui.Slider(0.0, 1.0)
            subdivisionsField = ui.Slider(0, 50)
            opacityField = ui.Slider(0.0, 1.0)
            lineWidthField = ui.Slider(0.0, 10.0)

            localPositionField = ui.VectorField()
            localRotationField = ui.VectorField()
            localScaleField = ui.VectorField()
            colorField = ui.ColorField(renderingSpace=True)

            lineStyleField = qtw.QComboBox()
            lineStyleField.setSizePolicy(qtw.QSizePolicy.Expanding, qtw.QSizePolicy.Minimum)

            for lineStyle in rigcontrol.LineStyle:
                lineStyleField.addItem(lineStyle.name.lower(), lineStyle.value)

            filledField = qtw.QCheckBox('Filled')
            xrayField = qtw.QCheckBox('X-Ray')

            for control in reversed(rigcontrol.getSelectedControls()):
                # reversed to show the values from the first selected rig control
                ui.bind(shapeTypeField, control, 'shapeType')
                ui.bind(sizeField, control, 'size', lambda value: round(value, 3))
                ui.bind(innerSizeField, control, 'innerSize', lambda value: round(value, 3))
                ui.bind(subdivisionsField, control, 'subdivisions')
                ui.bind(localPositionField, control, 'localPosition')
                ui.bind(localRotationField, control, 'localRotation')
                ui.bind(localScaleField, control, 'localScale')
                ui.bind(colorField, control, 'color')
                ui.bind(opacityField, control, 'opacity', lambda value: round(value, 3))
                ui.bind(lineWidthField, control, 'lineWidth', lambda value: round(value, 3))
                ui.bind(lineStyleField, control, 'lineStyle')
                ui.bind(filledField, control, 'filled')
                ui.bind(xrayField, control, 'xray')

            formLayout.addRow('Target', targetField)
            formLayout.addRow('Shape', shapeTypeField)
            formLayout.addRow('Size', sizeField)
            formLayout.addRow('Inner Size', innerSizeField)
            formLayout.addRow('Subdivisions', subdivisionsField)

            formLayout.addRow('', ui.LayoutSeparator())

            formLayout.addRow('Position', localPositionField)
            formLayout.addRow('Rotation', localRotationField)
            formLayout.addRow('Scale', localScaleField)

            formLayout.addRow('', ui.LayoutSeparator())

            formLayout.addRow('Color', colorField)
            formLayout.addRow('Opacity', opacityField)
            formLayout.addRow('Line Width', lineWidthField)
            formLayout.addRow('Line Style', lineStyleField)
            formLayout.addRow('', filledField)  # empty label to use CheckBox's text
            formLayout.addRow('', xrayField)  # empty label to use CheckBox's text
