# --------------------------------------------------------------------------- #
# Copyright (c) 2021 MOVINDOT ART S.R.L. (movindot.com). All rights reserved. #
# See eula.txt in the project root for license information.                   #
# --------------------------------------------------------------------------- #

"""The Animator's menu UI."""

import PySide2.QtWidgets as qtw
import puppeteer.ui as ui
import puppeteer.mayax as mx
import puppeteer.rigdefinition as rigdef
import puppeteer.rigger as rigger
import puppeteer.animator as animator
from .utils import showErrorMessage


def createMenuUI():
    """Create the UI for the menu bar."""
    with qtw.QMenuBar() as menuBar:
        ui.addStyleClass(menuBar, 'main-menu')

        fileMenu = menuBar.addMenu('File')
        fileMenu.addAction('Import Rig', importRig)
        fileMenu.addAction('Export Rig', exportRig)


def importRig():
    """Import a rig from a definition file."""
    selection = mx.cmd.ls(selection=True)

    if len(selection) > 1:
        showErrorMessage('Too many objects selected.\nSelect a target root.')

        return

    targetRoot = selection[0] if selection else None

    filePath = qtw.QFileDialog.getOpenFileName(
        caption='Load Rig',
        dir=mx.getCurrentProjectDirectory(),
        filter=f'Puppeteer Rig (*.{rigdef.RIG_FILE_EXTENSION})',
    )[0]

    if not filePath:
        return

    try:
        animator.importRig(filePath, targetRoot)
    except (animator.AnimatorError, rigger.RiggerError) as error:
        showErrorMessage(str(error))


def exportRig():
    """Export the rig to a definition file."""
    selection = mx.cmd.ls(selection=True)

    if len(selection) != 1:
        if not selection:
            showErrorMessage('Select a group.')
        else:
            showErrorMessage('Too many objects selected.\nSelect a group.')

        return

    filePath = qtw.QFileDialog.getSaveFileName(
        None,
        'New Rig',
        f'{mx.getCurrentProjectDirectory()}new_rig',
        f'Puppeteer Rig (*.{rigdef.RIG_FILE_EXTENSION})',
    )[0]

    if not filePath:
        return

    try:
        rigger.exportRig(selection[0], filePath)
    except rigger.RiggerError as error:
        showErrorMessage(str(error))
