# --------------------------------------------------------------------------- #
# Copyright (c) 2021 MOVINDOT ART S.R.L. (movindot.com). All rights reserved. #
# See eula.txt in the project root for license information.                   #
# --------------------------------------------------------------------------- #

"""Dynamics functionality."""

import puppeteer.mayax as mx
import puppeteer.animutils as animutils


def getControlParticle(control):
    """Get the rig control's particle."""
    try:
        return control.particle
    except mx.MayaAttributeError:
        return None


@mx.undoable
def convertControlToParticle(control):
    """Convert the rig control to particle."""
    group = mx.cmd.group(empty=True, name='particle_grp', parent=control)
    group.inheritsTransform = False
    group.hiddenInOutliner = True
    group.visibility = False

    controlProxy = animutils.transferAnimationToLocators([control])[0]

    emitter = mx.cmd.emitter(position=control.worldPosition, name=f'{control.name}_emitter')[0]
    particle, particleShape = mx.cmd.particle(name=f'{control.name}_particle')

    mx.cmd.connectDynamic(particle, emitters=emitter)
    mx.cmd.goal(particle, goal=controlProxy)

    particleShape.maxCount = 1
    particleShape.startFrame = -50
    particleShape.goalSmoothness = 2

    particleTracker = mx.cmd.spaceLocator(name=f'{control.name}_particleTracker')[0]
    particleShape['worldCentroid'].connect(particleTracker['translate'])

    emitter.parent = group
    particle.parent = group
    controlProxy.parent = group
    particleTracker.parent = group

    mx.cmd.matchTransform(emitter, control)
    mx.cmd.matchTransform(particle, control)

    mx.cmd.cutKey(control, clear=True, time=(), attribute='translate')

    particleConstraint = mx.cmd.pointConstraint(particleTracker, control)[0]
    particleConstraint.parent = group

    control.addAttr('particle', particle)

    control.select()


@mx.undoable
def bakeControlParticle(control):
    """Bake the particle motion to the rig control."""
    animutils.bake(control)

    control.particle.parent.delete()

    control.deleteAttr('particle')

    control.select()
