# --------------------------------------------------------------------------- #
# Copyright (c) 2021 MOVINDOT ART S.R.L. (movindot.com). All rights reserved. #
# See eula.txt in the project root for license information.                   #
# --------------------------------------------------------------------------- #

"""Utility functions that makes working with Maya easier."""

import os
from . import cmd


def getCurrentProjectDirectory():
    """Return the path for the selected project directory."""
    return cmd.workspace(query=True, rootDirectory=True)


def getModulesDirectory():
    """Return the path for the modules directory."""
    return os.path.normpath(
        os.path.join(
            cmd.internalVar(userAppDir=True),
            cmd.about(version=True),
            'modules',
        )
    )


def removeNodeFromDagContainer(node, container):
    """Force node removal from a `dagContainer`.

    A `dagContainer` cannot be set as `current` properly: nodes cannot be removed from it.
    Actually, they get removed, but the outliner still shows the nodes under the container.
    Also, the parent is not maintained.
    """
    nodeParent = node.parent

    # Re-adding the node to the container before removing it seems to do the trick.
    cmd.container(container, edit=True, addNode=[node])
    cmd.container(container, edit=True, removeNode=[node])

    if nodeParent != container:
        node.setParent(nodeParent, relative=True)
