# --------------------------------------------------------------------------- #
# Copyright (c) 2021 MOVINDOT ART S.R.L. (movindot.com). All rights reserved. #
# See eula.txt in the project root for license information.                   #
# --------------------------------------------------------------------------- #

"""Rig definition functionality."""

import json
import puppeteer.mayax as mx
import puppeteer.ui as ui
import puppeteer.rigcontrol as rigcontrol


RIG_FILE_EXTENSION = 'rig'


class RigDefinition(ui.BindableData):
    """Rig definition."""

    root = None
    targetRoot = None
    controls = []
    presets = []

    class Control(ui.BindableData):
        path = None
        targetPath = None
        position = mx.Vector.kZeroVector
        rotation = mx.Vector.kZeroVector
        scale = mx.Vector.kOneVector

        shapeType = rigcontrol.ShapeType.SPHERE
        size = 1.0
        innerSize = 0.0
        subdivisions = 0
        localPosition = mx.Vector.kZeroVector
        localRotation = mx.Vector.kZeroVector
        localScale = mx.Vector.kOneVector
        color = (1.222, 0.658, 0.064)
        opacity = 1.0
        lineWidth = 1.0
        lineStyle = rigcontrol.LineStyle.SOLID
        filled = True
        xray = True

    class Preset(ui.BindableData):
        name = None
        controls = []
        ikChains = []

    class PresetControl(ui.BindableData):
        path = None
        parentSpaces = []
        positionSpaces = []
        rotationSpaces = []
        scaleSpaces = []
        aimSpaces = []

    class PresetSpace(ui.BindableData):
        target = None
        weight = 1.0

    def save(self, filePath):
        """Save to a file."""
        with open(filePath, 'w') as dataFile:
            dataFile.write(self.jsonDump(beautify=True))

    def load(self, filePath):
        """Load from a file."""
        with open(filePath, 'r') as dataFile:
            self.jsonLoad(dataFile.read())

        return self

    def dumpPresets(self) -> str:
        """Dump presets to JSON."""
        return ui.BindableData.jsonDump(self.presets)

    def loadPresets(self, jsonPresets: str):
        """Load presets from JSON."""
        self.presets = json.loads(jsonPresets)

        return self
