# --------------------------------------------------------------------------- #
# Copyright (c) 2021 MOVINDOT ART S.R.L. (movindot.com). All rights reserved. #
# See eula.txt in the project root for license information.                   #
# --------------------------------------------------------------------------- #

"""Allow Qt UI to be created in a more declarative/tree-like style using context managers."""

import PySide2.QtWidgets as qtw
from .widgets import GroupBox


class _data:
    activeContainers = []


def _onLayoutEnter(layout):
    if _data.activeContainers:
        container = _data.activeContainers[-1]

        if isinstance(container, GroupBox) and container.layout():
            container.addLayout(layout)
        elif isinstance(container, qtw.QLayout):
            container.addLayout(layout)
        elif isinstance(container, qtw.QWidget):
            container.setLayout(layout)

    _data.activeContainers.append(layout)

    return layout


def _onWidgetEnter(widget):
    if _data.activeContainers:
        container = _data.activeContainers[-1]

        if not isinstance(container, qtw.QFormLayout):  # QFormLayout uses `addRow`
            container.addWidget(widget)

    _data.activeContainers.append(widget)

    return widget


def _onExit(*_args, **_kwargs):
    _data.activeContainers.pop(-1)


# --------------------------------------------------------------------------------------------------


qtw.QLayout.__enter__ = _onLayoutEnter
qtw.QLayout.__exit__ = _onExit

qtw.QWidget.__enter__ = _onWidgetEnter
qtw.QWidget.__exit__ = _onExit
